## 现货黄金日行情

接口：sge_daily

描述：获取上海黄金交易所现货合约日线行情

限量：单次最大2000，可循环或者分页提取

积分：用户积2000积分可调取，具体请参阅积分获取办法





注：数据由当日9:00至15:30的交易和前一日夜盘的20:00至2:30数据构成，成交量和成交金额为双向计量。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 合约代码，可通过基础信息获得 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 现货合约代码 |
| trade_date | str | Y | 交易日 |
| close | float | Y | 收盘点(元/克) |
| open | float | Y | 开盘点(元/克) |
| high | float | Y | 最高点(元/克) |
| low | float | Y | 最低点(元/克) |
| price_avg | float | Y | 加权平均价(元/克) |
| change | float | Y | 涨跌点位(元/克) |
| pct_change | float | Y | 涨跌幅 |
| vol | float | Y | 成交量(千克) |
| amount | float | Y | 成交金额(元) |
| oi | float | Y | 市场持仓 |
| settle_vol | float | Y | 交收量 |
| settle_dire | str | Y | 持仓方向 |

接口示例

```python
pro = ts.pro_api()

#获取单日统计数据
df = pro.sge_daily(trade_date='20220311')

#获取某合约指定日期，指定字段输出的数据
df = pro.sge_daily(ts_code='', start_date='20220301', end_date='20220311', fields='ts_code,close,open,vol')
```

数据示例

```python
ts_code trade_date     close      open      high       low         vol     settle_dire
0    Au99.95   20220311  403.3000  403.2000  403.3000  403.2000       24.00        None
```